@@ -4,7 +4,7 @@ use warnings;
 use base qw( SWISH::Prog::Result );
 use SWISH::3 ':constants';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -18,6 +18,9 @@ SWISH::Prog::Xapian::Result - search result for Swish3 Xapian backend
 
 =head1 METHODS
 
+Only new and overridden methods are documented here. See
+the L<SWISH::Prog::Result> documentation.
+
 =cut
 
 =head2 uri
@@ -62,6 +65,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/SWISH-Prog-Xapian>
