@@ -6,7 +6,7 @@ use SWISH::Prog::Xapian::Result;
 
 __PACKAGE__->mk_ro_accessors(qw( mset ));
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -20,6 +20,9 @@ SWISH::Prog::Xapian::Results - search results for Swish3 Xapian backend
 
 =head1 METHODS
 
+Only new and overridden methods are documented here. See
+the L<SWISH::Prog::Results> documentation.
+
 =cut
 
 =head2 mset
@@ -70,6 +73,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/SWISH-Prog-Xapian>
